@@ -1,27 +1,25 @@
 <?php
 
 /**
- * printer_friendly_top.php
- *
- * Copyright (c) 1999-2004 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
+ * printer_friendly top frame
  *
  * top frame of printer_friendly_main.php
  * displays some javascript buttons for printing & closing
  *
- * $Id: printer_friendly_top.php,v 1.14.2.1 2004/02/24 15:57:39 kink Exp $
+ * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: printer_friendly_top.php 12127 2007-01-13 20:07:24Z kink $
+ * @package squirrelmail
  */
 
-/* Path for SquirrelMail required files. */
+/**
+ * Path for SquirrelMail required files.
+ * @ignore
+ */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
 require_once(SM_PATH . 'include/validate.php');
-require_once(SM_PATH . 'functions/strings.php');
-require_once(SM_PATH . 'config/config.php');
-require_once(SM_PATH . 'include/load_prefs.php');
-require_once(SM_PATH . 'functions/page_header.php');
-require_once(SM_PATH . 'functions/html.php');
 
 displayHtmlHeader( _("Printer Friendly"),
              "<script language=\"javascript\" type=\"text/javascript\">\n".
@@ -34,7 +32,7 @@ displayHtmlHeader( _("Printer Friendly"),
              "</script>\n", FALSE );
 
 
-echo "<body text='$color[8]' bgcolor='$color[3]' link='$color[7]' vlink='$color[7]' alink='$color[7]'>\n" .
+echo '<body text="'.$color[8].'" bgcolor="'.$color[3].'" link="'.$color[7].'" vlink="'.$color[7].'" alink="'.$color[7]."\">\n" .
      html_tag( 'div',
          '<b>'.
          '<form>'.
@@ -43,6 +41,5 @@ echo "<body text='$color[8]' bgcolor='$color[3]' link='$color[7]' vlink='$color[
          '</form>'.
          '</b>',
      'right' );
-     '</body></html>'. "\n";
-
 ?>
+</body></html>
\ No newline at end of file
